==> microfrontends-0.0.10.tar.gz: lib/src/case_type.dart <==
import 'package:flutter/widgets.dart';
import 'extensions.dart';

typedef StateTypeMatchBuilder<T> = Widget Function(
  BuildContext context,
  T state,
);

final Map<CaseType, Map<Type, Branch>> _storage = {};

class Branch<T, K> {
  StateTypeMatchBuilder<K> builder;

  Branch(this.builder);

  Widget invoke(BuildContext context, K state) {
    return builder(context, state);
  }
}

class DefaultBranch<T> extends Branch<T, T> {
  DefaultBranch(StateTypeMatchBuilder<T> builder) : super(builder);
}

class CaseType<T> extends Widget {
  final Widget? child;

  const CaseType({this.child});

  void matches<K extends T>(StateTypeMatchBuilder<K> builder) {
    _storage[this] ??= {};
    _storage[this]![K] = Branch<T, K>(builder);
  }

  void otherwise(StateTypeMatchBuilder<T> builder) {
    _storage[this]![T] = DefaultBranch<T>(builder);
  }

  Widget build(BuildContext context) {
    Map<Type, Branch> typesMap = _storage[this]!;

    return context.subscribe<T>(builder: (context, state, child) {
      Branch? branch = typesMap[state.runtimeType];

      if (branch == null && typesMap[T] == null) {
        throw new Exception(
          'Neither ${state.runtimeType} or default case found',
        );
      }

      branch ??= typesMap[T]!;

      return branch.invoke(context, state);
    });
  }

  @override
  Element createElement() {
    return CaseTypeElement<T>(this);
  }
}

class CaseTypeElement<T> extends ComponentElement {
  CaseTypeElement(Widget widget) : super(widget);

  CaseType<T> get widget => super.widget as CaseType<T>;

  @override
  void update(CaseType newWidget) {
    final d = _storage.remove(widget)!;
    _storage[newWidget] = d;
    super.update(newWidget);
  }

  @override
  void unmount() {
    _storage.remove(widget);
    super.unmount();
  }

  @override
  Widget build() {
    return widget.build(this);
  }
}

==> microfrontends-0.0.13.tar.gz: lib/src/case_type.dart <==
import 'package:flutter/widgets.dart';
import 'extensions.dart';
import 'widgets.dart';

typedef StateTypeMatchBuilder<T> = Widget Function(
  BuildContext context,
  T state,
);

final Map<CaseType, Map<Type, Branch>> _storage = {};

class Branch<T, K> {
  StateTypeMatchBuilder<K> builder;

  Branch(this.builder);

  Widget invoke(BuildContext context, K state) {
    return builder(context, state);
  }
}

class DefaultBranch<T> extends Branch<T, T> {
  DefaultBranch(StateTypeMatchBuilder<T> builder) : super(builder);
}

class CaseType<T> extends Widget {
  final Widget? child;

  const CaseType({this.child});

  void matches<K extends T>(StateTypeMatchBuilder<K> builder) {
    _storage[this] ??= {};
    _storage[this]![K] = Branch<T, K>(builder);
  }

  void otherwise(StateTypeMatchBuilder<T> builder) {
    _storage[this]![T] = DefaultBranch<T>(builder);
  }

  Widget build(BuildContext context) {
    Map<Type, Branch> typesMap = _storage[this]!;

    return QueryBuilder<T>(builder: (context, state, child) {
      Branch? branch = typesMap[state.runtimeType];

      if (branch == null && typesMap[T] == null) {
        throw new Exception(
          'Neither ${state.runtimeType} or default case found',
        );
      }

      branch ??= typesMap[T]!;

      return branch.invoke(context, state);
    });
  }

  @override
  Element createElement() {
    return CaseTypeElement<T>(this);
  }
}

class CaseTypeElement<T> extends ComponentElement {
  CaseTypeElement(Widget widget) : super(widget);

  CaseType<T> get widget => super.widget as CaseType<T>;

  @override
  void update(CaseType newWidget) {
    final d = _storage.remove(widget)!;
    _storage[newWidget] = d;
    super.update(newWidget);
  }

  @override
  void unmount() {
    _storage.remove(widget);
    super.unmount();
  }

  @override
  Widget build() {
    return widget.build(this);
  }
}
